# frozen_string_literal: true

class QueueFixVulnerabilityReadsHasIssues < Gitlab::Database::Migration[2.1]
  MIGRATION = "FixVulnerabilityReadsHasIssues"
  DELAY_INTERVAL = 2.minutes
  BATCH_SIZE = 1000
  MAX_BATCH_SIZE = 10_000
  SUB_BATCH_SIZE = 200

  disable_ddl_transaction!
  restrict_gitlab_migration gitlab_schema: :gitlab_main

  def up
    queue_batched_background_migration(
      MIGRATION,
      :vulnerability_issue_links,
      :vulnerability_id,
      job_interval: DELAY_INTERVAL,
      batch_size: BATCH_SIZE,
      sub_batch_size: SUB_BATCH_SIZE,
      max_batch_size: MAX_BATCH_SIZE
    )
  end

  def down
    delete_batched_background_migration(MIGRATION, :vulnerability_issue_links, :vulnerability_id, [])
  end
end
